Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/mono/mono.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAlexander Köplinger <alex.koeplinger@outlook.com>2021-03-15 15:10:25 +0300
committerAlexander Köplinger <alex.koeplinger@outlook.com>2021-03-15 15:10:25 +0300
commit83cbc378af35346ae538d787d46dac209e8fd6da (patch)
treebce885c5107d28a17cdb045a51944ad6355bc327 /scripts
parent79b6e3f256a59ede74596ce82547f320bf1e9a99 (diff)
Rename master branch to main
Diffstat (limited to 'scripts')
-rw-r--r--scripts/ci/mono-ci.yml4
-rw-r--r--scripts/ci/mono-mono-signing.yml4
-rw-r--r--scripts/ci/pipeline/osx-package.groovy6
-rw-r--r--scripts/ci/pipeline/sdks-archive.groovy10
4 files changed, 12 insertions, 12 deletions
diff --git a/scripts/ci/mono-ci.yml b/scripts/ci/mono-ci.yml
index f8cf3d4f08b..e2b9ff4b051 100644
--- a/scripts/ci/mono-ci.yml
+++ b/scripts/ci/mono-ci.yml
@@ -2,7 +2,7 @@ trigger:
batch: true
branches:
include:
- - master
+ - main
- 20*-*
paths:
include:
@@ -22,7 +22,7 @@ trigger:
pr:
branches:
include:
- - master
+ - main
- 20*-*
paths:
include:
diff --git a/scripts/ci/mono-mono-signing.yml b/scripts/ci/mono-mono-signing.yml
index b288c0b5ef8..ab5339e2f32 100644
--- a/scripts/ci/mono-mono-signing.yml
+++ b/scripts/ci/mono-mono-signing.yml
@@ -2,9 +2,9 @@ parameters:
- name: mono_branch
displayName: Branch
type: string
- default: master
+ default: main
values:
- - master
+ - main
- 2020-02
- name: mono_commit
displayName: Full commit hash
diff --git a/scripts/ci/pipeline/osx-package.groovy b/scripts/ci/pipeline/osx-package.groovy
index 31d0a2ab15d..4a4ce0e350f 100644
--- a/scripts/ci/pipeline/osx-package.groovy
+++ b/scripts/ci/pipeline/osx-package.groovy
@@ -9,14 +9,14 @@ packageFileName = null
commitHash = null
utils = null
-if (monoBranch == 'master') {
+if (monoBranch == 'main') {
properties([ /* compressBuildLog() */ // compression is incompatible with JEP-210 right now
pipelineTriggers([cron('0 3 * * *')])
])
// multi-branch pipelines still get triggered for each commit, skip these builds on master by checking whether this build was timer-triggered or manually triggered
if (currentBuild.getBuildCauses('hudson.triggers.TimerTrigger$TimerTriggerCause').size() == 0 && currentBuild.getBuildCauses('hudson.model.Cause$UserIdCause').size() == 0) {
- echo "Skipping per-commit build on master."
+ echo "Skipping per-commit build on main."
return
}
}
@@ -9,14 +9,14 @@ packageFileName = null
pipelineTriggers([cron('0 3 * * *')])
])
- // multi-branch pipelines still get triggered for each commit, skip these builds on master by checking whether this build was timer-triggered or manually triggered
+ // multi-branch pipelines still get triggered for each commit, skip these builds on main by checking whether this build was timer-triggered or manually triggered
if (currentBuild.getBuildCauses('hudson.triggers.TimerTrigger$TimerTriggerCause').size() == 0 && currentBuild.getBuildCauses('hudson.model.Cause$UserIdCause').size() == 0) {
diff --git a/scripts/ci/pipeline/sdks-archive.groovy b/scripts/ci/pipeline/sdks-archive.groovy
index 260c843ab08..aa32ef38ee3 100644
--- a/scripts/ci/pipeline/sdks-archive.groovy
+++ b/scripts/ci/pipeline/sdks-archive.groovy
@@ -2,14 +2,14 @@ isPr = (env.ghprbPullId && !env.ghprbPullId.empty ? true : false)
monoBranch = (isPr ? "pr" : env.BRANCH_NAME)
jobName = env.JOB_NAME.split('/').first()
-if (monoBranch == 'master') {
+if (monoBranch == 'main') {
properties([ /* compressBuildLog() */ // compression is incompatible with JEP-210 right now
pipelineTriggers([cron('0 3 * * *')])
])
// multi-branch pipelines still get triggered for each commit, skip these builds on master by checking whether this build was timer-triggered or manually triggered
if (currentBuild.getBuildCauses('hudson.triggers.TimerTrigger$TimerTriggerCause').size() == 0 && currentBuild.getBuildCauses('hudson.model.Cause$UserIdCause').size() == 0) {
- echo "Skipping per-commit build on master."
+ echo "Skipping per-commit build on main."
return
}
}
@@ -72,8 +72,8 @@ parallel (
}
},
"WASM Linux": {
- if (monoBranch != 'master') {
- echo "Skipping WASM build on non-master branch."
+ if (monoBranch != 'main') {
+ echo "Skipping WASM build on non-main branch."
return
}
throttle(['provisions-wasm-toolchain']) {
@@ -2,14 +2,14 @@ isPr = (env.ghprbPullId && !env.ghprbPullId.empty ? true : false)
pipelineTriggers([cron('0 3 * * *')])
])
- // multi-branch pipelines still get triggered for each commit, skip these builds on master by checking whether this build was timer-triggered or manually triggered
+ // multi-branch pipelines still get triggered for each commit, skip these builds on main by checking whether this build was timer-triggered or manually triggered
if (currentBuild.getBuildCauses('hudson.triggers.TimerTrigger$TimerTriggerCause').size() == 0 && currentBuild.getBuildCauses('hudson.model.Cause$UserIdCause').size() == 0) {